@@ -1,6 +1,7 @@
 import argparse
 import importlib
-from celescope.tools.utils import *
+
+import celescope.tools.utils as utils
 from celescope.__init__ import __VERSION__, ASSAY_DICT
 
 
@@ -19,12 +20,12 @@ def main():
         subparser_2ed = subparser_1st.add_subparsers()
 
         # import __STEPS__
-        init_module = find_assay_init(assay)
+        init_module = utils.find_assay_init(assay)
         __STEPS__ = init_module.__STEPS__
 
         for step in __STEPS__:
             # import function and opts
-            step_module = find_step_module(assay, step)
+            step_module = utils.find_step_module(assay, step)
             func = getattr(step_module, step)
             func_opts = getattr(step_module, f"get_opts_{step}")
             parser_step = subparser_2ed.add_parser(step, formatter_class=argparse.ArgumentDefaultsHelpFormatter)
