@@ -1,6 +1,6 @@
 import argparse
 import os
-from celescope.tools.utils import parse_match_dir
+from celescope.tools.utils import *
 
 CITESEQ_DIR = os.path.dirname(__file__)
 
