@@ -95,7 +95,7 @@ def main():
 
         # adapt
         step = "cutadapt"
-        fq = f'{outdir_dic["barcode"]}/{sample}_2.fq.gz'
+        fq = f'{outdir_dic["barcode"]}/{sample}_2.fq{self.fq_suffix}'
         cmd = (
             f'{app} {assay} {step} '
             f'--fq {fq} --sample {sample} --outdir '
@@ -109,7 +109,7 @@ def main():
 
         # mapping_tag
         step = 'mapping_tag'
-        fq = f'{outdir_dic["cutadapt"]}/{sample}_clean_2.fq.gz'
+        fq = f'{outdir_dic["cutadapt"]}/{sample}_clean_2.fq{self.fq_suffix}'
         cmd = (
             f'{app} {assay} {step} '
             f'--sample {sample} '
