@@ -1,5 +1,4 @@
-from celescope.__init__ import __CONDA__
-from celescope.rna.__init__ import __STEPS__, __ASSAY__
+from celescope.rna.__init__ import __ASSAY__
 from celescope.tools.Multi import Multi
 
 
@@ -7,7 +6,7 @@ class Multi_rna(Multi):
     pass
 
 def main():
-    multi = Multi_rna(__ASSAY__, __STEPS__, __CONDA__)
+    multi = Multi_rna(__ASSAY__)
     multi.run()
 
 if __name__ == '__main__':
