@@ -29,13 +29,12 @@ def STAR_virus(args):
 
 def get_opts_STAR_virus(parser, sub_program):
     if sub_program:
-        parser.add_argument('--outdir', help='output dir', required=True)
-        parser.add_argument('--sample', help='sample name', required=True)
+        s_common(parser)
         parser.add_argument("--input_read", required=True)
-        parser.add_argument("--thread", help='STAR thread', default=1)
-        parser.add_argument('--assay', help='assay', required=True)
+
     parser.add_argument(
         '--virus_genomeDir',
         help='virus genome dir',
         required=True)
     parser.add_argument("--outFilterMatchNmin", help='STAR outFilterMatchNmin', default=35)
+    parser.add_argument('--starMem', help='starMem', default=30)
