@@ -8,15 +8,29 @@ class Multi_snp(Multi):
         step = 'STAR'
         cmd_line = self.get_cmd_line(step, sample)
         if self.args.not_consensus:
-            fq = f'{self.outdir_dic[sample]["cutadapt"]}/{sample}_clean_2.fq.gz'
+            fq = f'{self.outdir_dic[sample]["cutadapt"]}/{sample}_clean_2.fq{self.fq_suffix}'
         else:
-            fq = f'{self.outdir_dic[sample]["consensus"]}/{sample}_consensus.fq'         
+            fq = f'{self.outdir_dic[sample]["consensus"]}/{sample}_consensus.fq'
+            cmd_line += ' --consensus_fq '
+   
         cmd = (
             f'{cmd_line} '
             f'--fq {fq} '
         )
         self.process_cmd(cmd, step, sample, m=self.args.starMem, x=self.args.thread)
 
+    def target_metrics(self, sample):
+        step = 'target_metrics'
+        cmd_line = self.get_cmd_line(step, sample)
+        bam = f'{self.outdir_dic[sample]["featureCounts"]}/{sample}_name_sorted.bam'
+        cmd = (
+            f'{cmd_line} '
+            f'--bam {bam} '
+            f'--match_dir {self.col4_dict[sample]} '
+        )
+        self.process_cmd(cmd, step, sample, m=2, x=1)
+
+
     def snpCalling(self, sample):
         step = 'snpCalling'
         cmd_line = self.get_cmd_line(step, sample)
@@ -43,23 +57,6 @@ class Multi_snp(Multi):
         )
         self.process_cmd(cmd, step, sample, m=8, x=1)
 
-    def run_steps(self):
-        """ steps --not_consensus
-        """
-        if self.args.steps_run == 'all':
-            self.steps_run = self.__STEPS__
-        elif self.args.steps_run:
-            self.steps_run = self.args.steps_run.strip().split(',')
-        if self.args.not_consensus:
-            try:
-                self.steps_run.remove('consensus')
-            except ValueError as error:
-                pass
-
-        for sample in self.fq_dict:
-            self.last_step = ''
-            for step in self.steps_run:
-                eval(f'self.{step}(sample)')
 
 def main():
     multi = Multi_snp(__ASSAY__)
