@@ -1,11 +1,15 @@
 import os
 import glob
-import sys
 import argparse
-import re
+import itertools
 from collections import defaultdict
-from celescope.tools.utils import *
-from celescope.tools.__init__ import __PATTERN_DICT__
+
+import celescope
+from celescope.tools.utils import find_assay_init, find_step_module
+
+
+TOOLS_DIR = os.path.dirname(celescope.tools.__file__)
+
 
 class Multi():
 
@@ -13,16 +17,10 @@ class Multi():
         self.__ASSAY__ = assay
         init_module = find_assay_init(assay)
         self.__STEPS__ = init_module.__STEPS__
-        self.__CONDA__ = os.environ['CONDA_DEFAULT_ENV']
+        self.__CONDA__ = os.path.basename(os.environ['CONDA_DEFAULT_ENV'])
         self.__APP__ = 'celescope'
         self.col4_default = None
         self.last_step = ''
-        self.step_prefix = (
-            '{self.__APP__} {self.__ASSAY__} {step} '
-            '--outdir {self.outdir_dic[sample][step]} '
-            '--sample {sample} '
-            '--assay {self.__ASSAY__} '
-        )
         self.args = None
 
     def common_args(self):
@@ -50,12 +48,6 @@ class Multi():
         self.parser = parser
         return parser
 
-    def read_common_args(self):
-        if os.path.basename(self.__CONDA__) == 'celescope_RD':
-            self.debug_str = '--debug'
-        else:
-            self.debug_str = Multi.arg_str(self.args.debug, 'debug')
-
     def step_args(self):
         for step in self.__STEPS__:
             step_module = find_step_module(self.__ASSAY__, step)
@@ -66,18 +58,59 @@ class Multi():
         self.common_args()
         self.step_args()
         self.args = self.parser.parse_args()
-        if not self.args.not_gzip:
+        if self.args.gzip:
             self.fq_suffix = ".gz"
         else:
             self.fq_suffix = ""
 
+    @staticmethod
+    def parse_map_col4(mapfile, default_val):
+        fq_dict = defaultdict(list)
+        col4_dict = {}
+        with open(mapfile) as fh:
+            for line in fh:
+                line = line.strip()
+                if not line or line.startswith('#'):
+                    continue
+                tmp = line.split()
+                library_id, library_path, sample_name = tmp[:3]
+                if len(tmp) == 4:
+                    col4 = tmp[3]
+                else:
+                    col4 = default_val
+                fq1, fq2 = get_fq(library_id, library_path)
+
+                if sample_name in fq_dict:
+                    fq_dict[sample_name][0].append(fq1)
+                    fq_dict[sample_name][1].append(fq2)
+                else:
+                    fq_dict[sample_name] = [[fq1], [fq2]]
+                    col4_dict[sample_name] = col4
+
+
+        for sample_name in fq_dict:
+            fq_dict[sample_name][0] = ",".join(fq_dict[sample_name][0])
+            fq_dict[sample_name][1] = ",".join(fq_dict[sample_name][1])
+
+        if not fq_dict:
+            raise Exception('empty mapfile!')
+        return fq_dict, col4_dict
+
+    def link_data(self):
+        raw_dir = f'{self.args.outdir}/data_give/rawdata'
+        os.system('mkdir -p %s' % (raw_dir))
+        with open(raw_dir + '/ln.sh', 'w') as fh:
+            fh.write('cd %s\n' % (raw_dir))
+            for s, arr in self.fq_dict.items():
+                fh.write('ln -sf %s %s\n' % (arr[0], s + '_1.fq.gz'))
+                fh.write('ln -sf %s %s\n' % (arr[1], s + '_2.fq.gz'))
 
     def prepare(self):
         # parse_mapfile
-        self.fq_dict, self.col4_dict = parse_map_col4(self.args.mapfile, self.col4_default)
+        self.fq_dict, self.col4_dict = self.parse_map_col4(self.args.mapfile, self.col4_default)
 
         # link
-        link_data(self.args.outdir, self.fq_dict)      
+        self.link_data()      
 
         # mk log dir
         self.logdir = self.args.outdir + '/log'
@@ -98,10 +131,12 @@ class Multi():
                 self.outdir_dic[sample].update({step: step_outdir})
                 index += 1
     
-    def generate_cmd(self, cmd, step, sample, m, x):
+    def generate_cmd(self, cmd, step, sample, m=1, x=1):
+        if sample:
+            sample = "_" + sample
         self.sjm_cmd += f'''
 job_begin
-    name {step}_{sample}
+    name {step}{sample}
     sched_options -w n -cwd -V -l vf={m}g,p={x}
     cmd source activate {self.__CONDA__}; {cmd}
 job_end
@@ -136,6 +171,8 @@ job_end
             f'--thread {self.args.thread} '
         )
         cmd_line = step_prefix
+        if self.__CONDA__ == "celescope_RD":
+            cmd_line += " --debug "
         for arg in args_dict:
             if args_dict[arg] is False:
                 continue
@@ -143,7 +180,13 @@ job_end
                 cmd_line += f'--{arg} '
             else:
                 if args_dict[arg]:
-                    cmd_line += f'--{arg} {args_dict[arg]} '
+                    matches = [' ', '-']
+                    arg_string = str(args_dict[arg])
+                    if any(char in arg_string for char in matches): # need quote
+                        cmd_line += f'--{arg} "{arg_string}" '
+                    else:
+                        cmd_line += f'--{arg} {arg_string} '
+
         return cmd_line
 
     def sample(self, sample):
@@ -203,6 +246,7 @@ job_end
         cmd = (
             f'{cmd_line} '
             f'--bam {bam} '
+            f'--force_cell_num {self.col4_dict[sample]} '
         )
 
         self.process_cmd(cmd, step, sample, m=10, x=1)
@@ -240,20 +284,27 @@ job_end
             for step in self.steps_run:
                 eval(f'self.{step}(sample)')
 
+    def merge_report(self):    
+        step = "merge_report"
+        steps_str = ",".join(self.__STEPS__)
+        samples = ','.join(self.fq_dict.keys())
+        app = TOOLS_DIR + '/merge_table.py'
+        cmd = (
+            f'python {app} --samples {samples} '
+            f'--steps {steps_str} --outdir {self.args.outdir}'
+        )
+        if self.args.rm_files:
+            cmd += ' --rm_files'
+        self.generate_cmd(cmd, step, sample="")
+        for sample in self.fq_dict:
+            self.sjm_order += f'order {step} after {self.last_step}_{sample}\n'
+
     def end(self):
         if self.args.mod == 'sjm':
-            step = 'merge_report'
-            merge_report(
-                self.fq_dict,
-                self.__STEPS__,
-                self.last_step,
-                self.sjm_cmd,
-                self.sjm_order,
-                self.logdir,
-                self.__CONDA__,
-                self.args.outdir,
-                self.args.rm_files,
-            )
+            self.merge_report()
+            with open(self.logdir + '/sjm.job', 'w') as fh:
+                fh.write(self.sjm_cmd + '\n')
+                fh.write(self.sjm_order)
         if self.args.mod == 'shell':
             os.system('mkdir -p ./shell/')
             for sample in self.shell_dict:
@@ -267,5 +318,41 @@ job_end
         self.end()
 
 
+def get_read(library_id, library_path, read='1'):
+    read1_list = [f'_{read}', f'R{read}', f'R{read}_001']
+    fq_list = ['fq', 'fastq']
+    suffix_list = ["", ".gz"]
+    read_pattern_list = [
+        f'{library_path}/*{library_id}*{read}.{fq_str}{suffix}'
+        for read in read1_list
+        for fq_str in fq_list
+        for suffix in suffix_list
+    ]
+    fq_list = [glob.glob(read1_pattern) for read1_pattern in read_pattern_list]
+    fq_list = (non_empty for non_empty in fq_list if non_empty)
+    fq_list = sorted(list(itertools.chain(*fq_list)))
+    if len(fq_list) == 0:
+        print("Allowed R1 patterns:")
+        for pattern in read_pattern_list:
+            print(pattern)
+        raise Exception(
+            '\n'
+            f'Invalid Read{read} path! \n'
+            f'library_id: {library_id}\n'
+            f'library_path: {library_path}\n'
+        )
+    return fq_list
+
+
+def get_fq(library_id, library_path):
+    fq1_list = get_read(library_id, library_path, read='1')
+    fq2_list = get_read(library_id, library_path, read='2')
+    if len(fq1_list) != len(fq2_list):
+        raise Exception("Read1 and Read2 fastq number do not match!")
+    fq1 = ",".join(fq1_list)
+    fq2 = ",".join(fq2_list)
+    return fq1, fq2
+
+
+
 
-    
\ No newline at end of file
