@@ -1,78 +1,61 @@
-from collections import defaultdict
 import pysam
-import gzip
 import numpy as np
 import subprocess
-import os
 from xopen import xopen
-from celescope.tools.utils import *
-from celescope.tools.report import reporter
+from collections import defaultdict
+from itertools import groupby
+
+from celescope.tools.Step import Step, s_common
+import celescope.tools.utils as utils
 
 
-@add_log
+@utils.add_log
 def sort_fastq(fq, fq_tmp_file, outdir):
     tmp_dir = f'{outdir}/tmp'
     cmd = (
         f'mkdir {tmp_dir};'
-        f'zcat {fq} | paste - - - - | sort -T {tmp_dir} -k1,1 -t " " | tr "\t" "\n" > {fq_tmp_file};'
+        f'less {fq} | paste - - - - | sort -T {tmp_dir} -k1,1 -t " " | tr "\t" "\n" > {fq_tmp_file};'
     )
     subprocess.check_call(cmd, shell=True)
 
 
-@add_log
+@utils.add_log
 def sorted_dumb_consensus(fq, outfile, threshold):
     '''
-    read in name sorted fastq, output (barcode,umi) consensus fastq
+    consensus read in name-sorted fastq
+    output (barcode,umi) consensus fastq
     '''
-    curr_combine = ""
     read_list = []
-    n = 0
+    n_umi = 0
     total_ambiguous_base_n = 0
     length_list = []
     out_h = xopen(outfile, 'w')
 
+    def keyfunc(read):
+        attr = read.name.split('_')
+        return (attr[0], attr[1])
+
     with pysam.FastxFile(fq) as fh:
-        for entry in fh:
-            attr = entry.name.split('_')
-            barcode = attr[0]
-            umi = attr[1]
-            combine = [barcode,umi]
-            if combine != curr_combine:
-                # first
-                if curr_combine == "":
-                    curr_combine = combine
-                    read_list.append([entry.sequence,entry.quality])
-                    continue
-                consensus, consensus_qual, ambiguous_base_n, con_len = dumb_consensus(
-                    read_list, threshold=threshold, ambiguous="N")
-                n += 1
-                prefix = "_".join(curr_combine)
-                read_name = f'{prefix}_{n}'
-                out_h.write(fastq_line(read_name,consensus,consensus_qual))
-                if n % 10000 == 0:
-                    sorted_dumb_consensus.logger.info(f'{n} UMI done.')
-                total_ambiguous_base_n += ambiguous_base_n
-                length_list.append(con_len)
-                read_list = []
-                curr_combine = combine
-            read_list.append([entry.sequence,entry.quality])
-    #last
-    consensus, consensus_qual, ambiguous_base_n, con_len = dumb_consensus(
-        read_list, threshold=threshold, ambiguous="N")
-    n += 1
-    prefix = "_".join(curr_combine)
-    read_name = f'{prefix}_{n}'
-    out_h.write(fastq_line(read_name,consensus,consensus_qual))
-    if n % 10000 == 0:
-        sorted_dumb_consensus.logger.info(f'{n} UMI done.')
-    total_ambiguous_base_n += ambiguous_base_n
-    length_list.append(con_len)
+        for (barcode, umi), g in groupby(fh, key=keyfunc):
+            read_list = []
+            for read in g:
+                read_list.append([read.sequence, read.quality])
+            consensus_seq, consensus_qual, ambiguous_base_n, con_len = dumb_consensus(
+                read_list, threshold=threshold, ambiguous="N")
+            n_umi += 1
+            prefix = "_".join([barcode, umi])
+            read_name = f'{prefix}_{n_umi}'
+            out_h.write(utils.fastq_line(read_name, consensus_seq, consensus_qual))
+            if n_umi % 10000 == 0:
+                sorted_dumb_consensus.logger.info(f'{n_umi} UMI done.')
+            total_ambiguous_base_n += ambiguous_base_n
+            length_list.append(con_len)
     
     out_h.close()
-    return n, total_ambiguous_base_n, length_list
+    return n_umi, total_ambiguous_base_n, length_list
 
 
-@add_log
+@utils.add_log
 def wrap_consensus(fq, outdir, sample, threshold):
     fq_tmp_file = f'{outdir}/{sample}_sorted.fq.tmp'
     sort_fastq(fq, fq_tmp_file, outdir)
@@ -94,7 +77,7 @@ def dumb_consensus(read_list, threshold=0.5, ambiguous='N', default_qual='F'):
     '''
 
     con_len = get_read_length(read_list, threshold=threshold)
-    consensus = ""
+    consensus_seq = ""
     consensus_qual = ""
     ambiguous_base_n = 0
     for n in range(con_len):
@@ -121,7 +104,7 @@ def dumb_consensus(read_list, threshold=0.5, ambiguous='N', default_qual='F'):
                 break
         if consensus_atom == ambiguous:
             ambiguous_base_n += 1
-        consensus += consensus_atom
+        consensus_seq += consensus_atom
 
         max_freq_qual = 0
         consensus_base_qual = default_qual
@@ -131,7 +114,7 @@ def dumb_consensus(read_list, threshold=0.5, ambiguous='N', default_qual='F'):
                 consensus_base_qual = base_qual
 
         consensus_qual += consensus_base_qual
-    return consensus, consensus_qual, ambiguous_base_n, con_len
+    return consensus_seq, consensus_qual, ambiguous_base_n, con_len
 
 
 def get_read_length(read_list, threshold=0.5):
@@ -155,17 +138,21 @@ def get_read_length(read_list, threshold=0.5):
         if fraction >= threshold:
             return length
 
-
+@utils.add_log
 def consensus(args):
+
+    step_name = "consensus"
+    step = Step(args, step_name)
+
+    if args.not_consensus:
+        consensus.logger.warning("not_consensus!")
+        return
     sample = args.sample
     outdir = args.outdir
     assay = args.assay
     fq = args.fq
     threshold = float(args.threshold)
 
-    if not os.path.exists(outdir):
-        os.system('mkdir -p %s' % outdir)
-
     outfile, n, total_ambiguous_base_n, length_list = wrap_consensus(fq, outdir, sample, threshold)
 
     # metrics
@@ -173,11 +160,11 @@ def consensus(args):
     metrics["UMI Counts"] = n
     metrics["Mean UMI Length"] = np.mean(length_list)
     metrics["Ambiguous Base Counts"] = total_ambiguous_base_n    
-    format_metrics(metrics)
+    utils.format_metrics(metrics)
 
     ratios = {}
     ratios["Ambiguous Base Counts Ratio"] = total_ambiguous_base_n / sum(length_list)
-    format_ratios(ratios)
+    utils.format_ratios(ratios)
 
     # stat file
     stat_file = f'{outdir}/stat.txt'
@@ -189,13 +176,13 @@ def consensus(args):
         )
         stat_h.write(stat_str)
 
-    t = reporter(name='consensus', assay=args.assay, sample=args.sample,
-                 stat_file=stat_file, outdir=args.outdir + '/..')
-    t.get_report()
+    step.clean_up()
+
 
 
 def get_opts_consensus(parser, sub_program):
     parser.add_argument("--threshold", help='valid base threshold', default=0.5)
+    parser.add_argument("--not_consensus", help="input fastq is not consensus", action='store_true')
     if sub_program:
         s_common(parser)
         parser.add_argument("--fq", required=True)
\ No newline at end of file
