@@ -1,11 +1,9 @@
-#!/bin/env python
-# coding=utf8
-
 import os
 import sys
 import json
 import functools
 import gzip
+import random
 from collections import defaultdict
 from itertools import groupby
 import numpy as np
@@ -14,51 +12,26 @@ import subprocess
 from scipy.io import mmwrite
 from scipy.sparse import csr_matrix, coo_matrix
 import pysam
-from celescope.tools.utils import *
-from celescope.tools.report import reporter
+from celescope.tools.utils import add_log, format_number, glob_genomeDir, gene_convert, s_common, add_mem
 from celescope.tools.cellranger3.cell_calling_3 import cell_calling_3
 from celescope.tools.__init__ import MATRIX_FILE_NAME, FEATURE_FILE_NAME, BARCODE_FILE_NAME
-
+from celescope.tools.cellranger3 import get_plot_elements
+from celescope.tools.Step import Step
 
 toolsdir = os.path.dirname(__file__)
+random.seed(0)
+np.random.seed(0)
 
 
-def report_prepare(count_file, downsample_file, outdir):
-    """write data of saturation, gene, barcode-rank plot to .data.json
-    """
-
-    json_file = outdir + '/../.data.json'
-    if not os.path.exists(json_file):
-        data = {}
-    else:
-        fh = open(json_file)
-        data = json.load(fh)
-        fh.close()
+@add_log
+def report_prepare(count_file, downsample_file, step_obj):
 
     df0 = pd.read_table(downsample_file, header=0)
-    data['percentile'] = df0['percent'].tolist()
-    data['MedianGeneNum'] = df0['median_geneNum'].tolist()
-    data['Saturation'] = df0['saturation'].tolist()
-
-    df = pd.read_table(count_file, header=0)
-    df = df.sort_values('UMI', ascending=False)
-
-    # cellranger3 compatible
-    # density TODO
-    n_cell = df[df['mark'] == 'CB'].shape[0]
-    data['CB_num'] = n_cell
-    data['Cells'] = list(df.iloc[:n_cell,]["UMI"])
-
-    n_background = df[df['mark'] == 'UB'].shape[0]
-    data['UB_num'] = n_background
-    data['Background'] = list(df.iloc[n_cell:,]["UMI"])
-
-    data['umi_summary'] = True
-
-    with open(json_file, 'w') as fh:
-        json.dump(data, fh)
-
-
+    step_obj.add_data_item(percentile=df0['percent'].tolist())
+    step_obj.add_data_item(MedianGeneNum=df0['median_geneNum'].tolist())
+    step_obj.add_data_item(Saturation=df0['saturation'].tolist())
+    step_obj.add_data_item(chart=get_plot_elements.plot_barcode_rank(count_file))
+    step_obj.add_data_item(umi_summary=True)
 
 def hd(x, y):
     return len([i for i in range(len(x)) if x[i] != y[i]])
@@ -116,7 +89,7 @@ def bam2table(bam, detail_file):
                 for umi in res_dict[geneID]:
                     fh1.write('%s\t%s\t%s\t%s\n' % (barcode, geneID, umi,
                                                     res_dict[geneID][umi]))
-
+    samfile.close()
 
 
 @add_log
@@ -366,39 +339,67 @@ def get_summary(df, sample, Saturation, CB_describe, CB_total_Genes,
     summary.to_csv(stat_file, header=False, sep=':')
 
 
-def sample(p, df, bc):
-    tmp = df.sample(frac=p)
-    format_str = "%.2f\t%.2f\t%.2f\n"
-    tmp.reset_index(drop=True, inplace=True)
-    tmp = tmp.loc[tmp['Barcode'].isin(bc), :]
-    geneNum_median = tmp.groupby('Barcode').agg({
-        'geneID': 'nunique'
-    })['geneID'].median()
-    tmp = tmp.groupby(['Barcode', 'geneID', 'UMI']).agg({'UMI': 'count'})
-    total = float(tmp['UMI'].count())
-    saturation = (1 - tmp.loc[tmp['UMI'] == 1, :].shape[0] / total) * 100
-    return format_str % (p, geneNum_median, saturation), saturation
+@add_log
+def sub_sample(fraction, df_cell, cell_bc, cell_read_index):
+    '''
+    cell_bc - cell barcode
+    cell_read_index - df_cell repeat index
+    '''
+    cell_read = df_cell['count'].sum()
+    frac_n_read = int(cell_read * fraction)
+    subsample_read_index = cell_read_index[:frac_n_read]
+    index_dedup, counts = np.unique(subsample_read_index, return_counts=True)
+    n_count_once = np.sum(counts == 1)
+    # total = UMI
+    umi_total = len(index_dedup)
+    umi_saturation = round((1 - n_count_once / umi_total) * 100, 2)
+    read_total = frac_n_read
+    read_saturation = round((1 - n_count_once / read_total) * 100, 2)
+
+    # gene median
+    df_cell_subsample = df_cell.loc[index_dedup,]
+    geneNum_median = float(df_cell_subsample.groupby('Barcode').agg({'geneID': 'nunique'}).median())
+
+    return umi_saturation, read_saturation, geneNum_median
 
 
 @add_log
-def downsample(detail_file, cell_bc, downsample_file):
-    df = pd.read_table(detail_file, index_col=[0, 1, 2])
-    df = df.index.repeat(df['count']).to_frame()
+def downsample(df, cell_bc, downsample_file):
+    """saturation and median gene
+    return fraction=1 saturation
+    """
+    df_cell = df.loc[df["Barcode"].isin(cell_bc), :]
+    cell_read_index = np.array(df_cell.index.repeat(df_cell['count']))
+    np.random.shuffle(cell_read_index)
+
     format_str = "%.2f\t%.2f\t%.2f\n"
+    res_dict = {
+        "fraction": [],
+        "umi_saturation": [],
+        "read_saturation": [],
+        "median_gene": []
+    }
     with open(downsample_file, 'w') as fh:
         fh.write('percent\tmedian_geneNum\tsaturation\n')
         fh.write(format_str % (0, 0, 0))
+        for fraction in np.arange(0.1, 1.1, 0.1):
+            umi_saturation, read_saturation, geneNum_median = sub_sample(fraction, df_cell, cell_bc, cell_read_index)
+            fh.write(format_str % (fraction, geneNum_median, umi_saturation))
+            format_float = lambda x: round(x / 100, 4)
+            res_dict["fraction"].append(round(fraction, 1))
+            res_dict["umi_saturation"].append(format_float(umi_saturation))
+            res_dict["read_saturation"].append(format_float(read_saturation))
+            res_dict["median_gene"].append(geneNum_median)
 
-        saturation = 0
-        for p in np.arange(0.1, 1.1, 0.1):
-            r, s = sample(p=p, df=df, bc=cell_bc)
-            fh.write(r)
-            saturation = s
-    return saturation
+    return umi_saturation, res_dict
 
 
 @add_log
 def count(args):
+
+    step_name = "count"
+    step = Step(args, step_name)
+
     # args
     outdir = args.outdir
     sample = args.sample
@@ -413,10 +414,6 @@ def count(args):
     else:
         gtf_file = args.gtf
 
-    # 检查和创建输出目录
-    if not os.path.exists(outdir):
-        os.system('mkdir -p %s' % (outdir))
-
     # umi纠错，输出Barcode geneID  UMI     count为表头的表格
     count_detail_file = outdir + '/' + sample + '_count_detail.txt.gz'
     bam2table(args.bam, count_detail_file)
@@ -443,17 +440,13 @@ def count(args):
 
     # export cell matrix
     matrix_10X(df, outdir, sample, gtf_file, dir_name='matrix_10X', cell_bc=cell_bc)
-    (CB_total_Genes, CB_reads_count,
-        reads_mapped_to_transcriptome) = expression_matrix(
+    (CB_total_Genes, CB_reads_count, reads_mapped_to_transcriptome) = expression_matrix(
             df, cell_bc, outdir, sample, gtf_file)
 
     # downsampling
     cell_bc = set(cell_bc)
     downsample_file = args.outdir + '/' + args.sample + '_downsample.txt'
-    Saturation = downsample(
-        count_detail_file,
-        cell_bc,
-        downsample_file)
+    Saturation, res_dict = downsample(df, cell_bc, downsample_file)
 
     # summary
     stat_file = outdir + '/stat.txt'
@@ -461,22 +454,21 @@ def count(args):
                 CB_reads_count, reads_mapped_to_transcriptome, stat_file,
                 outdir + '/../')
 
-    report_prepare(marked_counts_file, downsample_file, outdir)
+    report_prepare(marked_counts_file, downsample_file, step)
+
+    step.add_content_item('metric', downsample_summary=res_dict)
+    step.clean_up()
+
 
-    t = reporter(assay=assay,
-                 name='count', sample=args.sample,
-                 stat_file=outdir + '/stat.txt',
-                 outdir=outdir + '/..')
-    t.get_report()
 
 
 def get_opts_count(parser, sub_program):
     if sub_program:
         parser = s_common(parser)
         parser.add_argument('--bam', required=True)
+        parser.add_argument('--force_cell_num', help='force cell number', default=None)
     parser.add_argument('--genomeDir', help='genome directory')
     parser.add_argument('--gtf', help='gtf file path')
-    parser.add_argument('--force_cell_num', help='force cell number', default=None)
     parser.add_argument('--expected_cell_num', help='expected cell number', default=3000)
     parser.add_argument('--cell_calling_method', help='cell calling methods', 
-        choices=['auto', 'cellranger3', 'inflection',], default='auto')
\ No newline at end of file
+        choices=['auto', 'cellranger3', 'inflection',], default='auto')
