@@ -3,13 +3,12 @@ import sys
 import re
 import subprocess
 import logging
-from itertools import islice
 import pandas as pd
 import pysam
 
+from itertools import islice
 from celescope.tools.utils import *
-from celescope.tools.report import reporter
-from celescope.tools.Fastq import Fastq
+from celescope.tools.Step import Step
 
 
 ADAPT = ['polyT=A{18}', 'p5=AGATCGGAAGAGCACACGTCTGAACTCCAGTCAC']
@@ -57,9 +56,9 @@ def read_adapter_fasta(adapter_fasta):
 
 @add_log
 def cutadapt(args):
-    # check dir
-    if not os.path.exists(args.outdir):
-        os.system('mkdir -p %s' % (args.outdir))
+
+    step_name = "cutadapt"
+    step = Step(args, step_name)
 
     adapter_args = read_adapter_fasta(args.adapter_fasta)
     adapter_args += ADAPT
@@ -70,7 +69,7 @@ def cutadapt(args):
         adapt.append('-a')
         adapt.append(a)
 
-    if not args.not_gzip:
+    if args.gzip:
         suffix = ".gz"
     else:
         suffix = ""
@@ -96,15 +95,7 @@ def cutadapt(args):
 
     format_stat(args.outdir + '/cutadapt.log', args.sample)
 
-    t = reporter(
-        name='cutadapt',
-        assay=args.assay,
-        sample=args.sample,
-        stat_file=args.outdir +
-        '/stat.txt',
-        outdir=args.outdir +
-        '/..')
-    t.get_report()
+    step.clean_up()    
 
 
 def get_opts_cutadapt(parser, sub_program):
@@ -115,7 +106,7 @@ def get_opts_cutadapt(parser, sub_program):
     parser.add_argument('--insert', help="read2 insert length", default=150)
     if sub_program:
         parser.add_argument('--fq', help='fq file', required=True)
-        parser.add_argument('--not_gzip', help="output fastq without gzip", action='store_true')
+        parser.add_argument('--gzip', help="output gzipped fastq", action='store_true')
         parser = s_common(parser)
     return parser
 
