@@ -5,14 +5,14 @@ import argparse
 import pandas as pd
 import io
 import logging
-from jinja2 import Environment, PackageLoader, select_autoescape, FileSystemLoader
+from jinja2 import Environment, PackageLoader, select_autoescape, FileSystemLoader, Undefined
 from celescope.tools.utils import *
 
+
 env = Environment(
     loader=FileSystemLoader(os.path.dirname(__file__) + '/../templates/'),
-    autoescape=select_autoescape(['html', 'xml'])
+    autoescape=select_autoescape(['html', 'xml']),
 )
-logger1 = logging.getLogger(__name__)
 
 
 class reporter:
@@ -35,7 +35,7 @@ class reporter:
         self.html_flag = html_flag
 
     def get_report(self):
-        logger1.info(f'generate report: {self.assay} {self.name}')
+
 
         json_file = self.outdir + '/.data.json'
         if not os.path.exists(json_file):
@@ -77,6 +77,5 @@ class reporter:
                 fh.write(html)
 
         with open(json_file, 'w') as fh:
-            json.dump(data, fh)
+            json.dump(data, fh, indent=4)
 
-        logger1.info('generate report done!')
