@@ -1,18 +1,18 @@
-#!/bin/env python
-# coding=utf8
-
 import os
 import pandas as pd
-import sys
+
 from celescope.__init__ import __VERSION__, ASSAY_DICT
-from celescope.tools.utils import *
-from celescope.tools.report import reporter
+import celescope.tools.utils as utils
 from celescope.tools.__init__ import __PATTERN_DICT__
 from .Chemistry import Chemistry
+from celescope.tools.Step import Step, s_common
 
 
-@add_log
+@utils.add_log
 def sample(args):
+    
+    step_name = "sample"
+    step = Step(args, step_name)
 
     sample_name = args.sample
     assay = args.assay
@@ -43,13 +43,8 @@ def sample(args):
     stat_file = outdir + "/stat.txt"
     stat.to_csv(stat_file, sep=":", header=None, index=False)
 
-    t = reporter(
-        name='sample',
-        assay=assay,
-        sample=sample_name,
-        stat_file=stat_file,
-        outdir=outdir + '/..')
-    t.get_report()
+    step.clean_up()
+
     return chemistry
 
 
