@@ -1,8 +1,4 @@
 import glob
-from celescope.vdj.__init__ import CHAINS
-from celescope.tools.report import reporter
-from celescope.tools.utils import *
-from celescope.tools.Analysis import Analysis
 import gzip
 import os
 import pandas as pd
@@ -16,6 +12,12 @@ import json
 mpl.use('Agg')
 from matplotlib import pyplot as plt
 
+from celescope.tools.Step import Step, s_common
+from celescope.vdj.__init__ import CHAINS
+from celescope.tools.report import reporter
+import celescope.tools.utils as utils
+from celescope.tools.Analysis import Analysis
+
 
 def report_prepare(df, outdir):
 
@@ -37,9 +39,12 @@ def report_prepare(df, outdir):
         json.dump(data, fh)
 
 
-@add_log
+@utils.add_log
 def count_vdj(args):
 
+    step_name = f"{args.type}_count_vdj"
+    step = Step(args, step_name)
+
     sample = args.sample
     match_dir = args.match_dir
     UMI_min = args.UMI_min
@@ -51,9 +56,6 @@ def count_vdj(args):
     iUMI = int(args.iUMI)
     chains = CHAINS[type]
 
-    if not os.path.exists(outdir):
-        os.system('mkdir -p %s' % outdir)
-
     # out file
     cell_confident_file = f"{outdir}/{sample}_cell_confident.tsv"
     cell_confident_count_file = f"{outdir}/{sample}_cell_confident_count.tsv"
@@ -67,7 +69,7 @@ def count_vdj(args):
     else:
         match_bool = True
     if match_bool:
-        match_cell_barcodes, match_cell_number = read_barcode_file(match_dir)
+        match_cell_barcodes, match_cell_number = utils.read_barcode_file(match_dir)
 
     cell_summary_row_list = []
 
@@ -84,7 +86,14 @@ def count_vdj(args):
     df_UMI_cell = df_UMI_sum[df_UMI_sum.UMI >= UMI_min]
     df_UMI_sum["mark"] = df_UMI_sum["UMI"].apply(
         lambda x: "CB" if (x >= UMI_min) else "UB")
-    report_prepare(df_UMI_sum, outdir + "/../")
+    
+    # data
+    df = df_UMI_sum.sort_values('UMI', ascending=False)
+    step.add_data_item(CB_num=df[df['mark'] == 'CB'].shape[0])
+    step.add_data_item(Cells=list(df.loc[df['mark'] == 'CB', 'UMI']))
+    step.add_data_item(UB_num= df[df['mark'] == 'UB'].shape[0])
+    step.add_data_item(Background=list(df.loc[df['mark'] == 'UB', 'UMI']))
+
 
     cell_barcodes = set(df_UMI_cell.barcode)
     cell_number = len(cell_barcodes)
@@ -325,7 +334,7 @@ def count_vdj(args):
         (cell_summary.total_count.astype("float")) * 100
     cell_summary["percent"] = cell_summary["percent"].apply(
         lambda x: round(x, 2))
-    cell_summary["count"] = cell_summary["count"].apply(format_number)
+    cell_summary["count"] = cell_summary["count"].apply(utils.format_number)
 
     def percent_str_func(row):
         need_percent = bool(
@@ -346,16 +355,7 @@ def count_vdj(args):
 
     cell_stat_file = "{}/stat.txt".format(outdir)
     gen_stat(cell_summary, cell_stat_file)
-    name = type + '_count_vdj'
-    t = reporter(
-        name=name,
-        sample=args.sample,
-        stat_file=cell_stat_file,
-        outdir=outdir + '/..',
-        assay=args.assay,
-        parameters={"iUMI": iUMI},
-    )
-    t.get_report()
+    step.add_data_item(iUMI=iUMI)
 
     # cloneytpes table
     def format_table(df_clonetypes):
@@ -378,18 +378,9 @@ def count_vdj(args):
         df_table, table_header = format_table(df_match_clonetypes)
         title = 'Match Clonetypes'
 
-    ana = Analysis(sample, outdir ,assay, match_dir=None, step='count_vdj')
-    table_dict = Analysis.get_table(title, 'clonetypes_table', df_table)
-    ana.report_prepare(table_dict=table_dict)
+    table_dict = step.get_table(title, 'clonetypes_table', df_table)
+    step.add_data_item(table_dict=table_dict)
     
-    t = reporter(
-        name="clonetypes",
-        sample=args.sample,
-        outdir=outdir + '/..',
-        assay=args.assay,
-    )
-    t.get_report()
-
     # other_metrics_file
     """
     if len(other_metrics_row_list) != 0:
@@ -397,12 +388,14 @@ def count_vdj(args):
         other_metrics.to_csv(other_metrics_file,sep=":",header=None,index=False)
     """
 
+    step.clean_up()
+
 
 def get_opts_count_vdj(parser, sub_program):
     if sub_program:
         parser = s_common(parser)
         parser.add_argument("--UMI_count_filter1_file", required=True)
-    parser.add_argument("--match_dir", default=None)
+        parser.add_argument("--match_dir", default=None)
     parser.add_argument("--type", required=True)
     parser.add_argument('--UMI_min', dest='UMI_min',
                         help='minimum UMI number to filter', default="auto")
