@@ -1,21 +1,20 @@
-from celescope.vdj.__init__ import CHAINS
-from celescope.tools.report import reporter
-from celescope.tools.utils import *
+'''
+vdj mapping
+'''
+
 import os
-import logging
-import gzip
-import numpy as np
 import pandas as pd
 import matplotlib as mpl
 import pysam
-import re
-import json
-import argparse
 mpl.use('Agg')
 from matplotlib import pyplot as plt
 
+from celescope.tools.Step import Step, s_common
+from celescope.vdj.__init__ import CHAINS
+import celescope.tools.utils as utils
 
-@add_log
+
+@utils.add_log
 def summary(input_file, alignments, type, outdir, sample, assay, debug, not_consensus):
     chains = CHAINS[type]
 
@@ -133,6 +132,8 @@ def summary(input_file, alignments, type, outdir, sample, assay, debug, not_cons
         sep="\t",
         index=False)
 
+    '''
+    #TODO
     if debug:
         unique_UMI = df_UMI.shape[0]
         mapping_summary_row_list.append({
@@ -146,6 +147,7 @@ def summary(input_file, alignments, type, outdir, sample, assay, debug, not_cons
             "count": UMI_after_Contamination_Filtering,
             "total_count": unique_UMI,
         })
+    '''
 
     # stat file
     df = pd.DataFrame(
@@ -155,22 +157,10 @@ def summary(input_file, alignments, type, outdir, sample, assay, debug, not_cons
             "count",
             "total_count"])
     stat_file = f'{outdir}/stat.txt'
-    gen_stat(df, stat_file)
-
-    # report
-    STEP = 'mapping_vdj'
-    name = f'{type}_{STEP}'
-    t = reporter(
-        name=name,
-        sample=sample,
-        stat_file=stat_file,
-        outdir=outdir + '/..',
-        assay=assay,
-    )
-    t.get_report()
+    utils.gen_stat(df, stat_file)
 
 
-@add_log 
+@utils.add_log 
 def mixcr(outdir, sample, input_file, thread, species):
     report = f"{outdir}/{sample}_align.txt"
     not_align_fq = f"{outdir}/not_align.fq"
@@ -197,26 +187,30 @@ mixcr exportAlignments \
     return alignments
 
 
-@add_log
+@utils.add_log
 def mapping_vdj(args):
+
+    step_name = f"{args.type}_mapping_vdj"
+    step = Step(args, step_name)
+
     sample = args.sample
     outdir = args.outdir
     fq = args.fq
-    type = args.type
+    receptor_type = args.type
     debug = args.debug
     assay = args.assay
     thread = int(args.thread)
     not_consensus = args.not_consensus
     species = args.species
 
-    if not os.path.exists(outdir):
-        os.system('mkdir -p %s' % outdir)
-
     input_file = fq
     alignments = mixcr(outdir, sample, input_file, thread, species)
 
     # summary
-    summary(input_file, alignments, type, outdir, sample, assay, debug, not_consensus)
+    summary(input_file, alignments, receptor_type, outdir, sample, assay, debug, not_consensus)
+
+    step.clean_up()
+
 
 
 def get_opts_mapping_vdj(parser, sub_program):
